-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or disclosure
--  restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

--
--  ES
-- 

CREATE TABLESPACE PLTS
IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 SEGSIZE 32
 DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;


-- *******************************************
-- Create persistentlock table and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.PERSISTENTLOCK (
   LOCKID INTEGER NOT NULL,
   SEQUENCEID INTEGER NOT NULL,
   OWNER INTEGER NOT NULL,
   MODULENAME VARCHAR(250),
   COMPNAME VARCHAR(250),
   METHOD VARCHAR(250),
   MSGHANDLESTRING VARCHAR(128),
   CONSTRAINT PK_PERSISTENTLOCK PRIMARY KEY (LOCKID, SEQUENCEID) )
IN @DB_NAME@.PLTS;

CREATE UNIQUE INDEX @SCHEMA@.PERSISTENTLOCK ON
 @SCHEMA@.PERSISTENTLOCK (LOCKID,SEQUENCEID)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@;
 
--
--  FEM
-- 
 
-- *******************************************
-- Create tablespaces
-- *******************************************
CREATE TABLESPACE EVENTS
IN @DB_NAME@ USING STOGROUP @STOGRP@
 CCSID UNICODE
 DEFINE NO
 SEGSIZE 32
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE16K@;

CREATE TABLESPACE EVENTS0
IN @DB_NAME@ USING STOGROUP @STOGRP@
 CCSID UNICODE
 DEFINE NO
 SEGSIZE 32
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE LOB TABLESPACE JSERVICE
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

-- *******************************************
-- create table FailedEvents and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FAILEDEVENTS (
    MSGID              VARCHAR(255) NOT NULL,
    DESTINATION_MODULE_NAME   VARCHAR(255),
    DESTINATION_COMPONENT_NAME   VARCHAR(255),
    DESTINATION_METHOD_NAME   VARCHAR(255),
    SOURCE_MODULE_NAME VARCHAR(255),
    SOURCE_COMPONENT_NAME   VARCHAR(255),
    RESUBMITDESTINATION   VARCHAR(512),
    INTERACTIONTYPE    VARCHAR(128),
    EXCEPTIONDETAILS   VARCHAR(1024),
    SESSIONID          VARCHAR(255),
    CORRELATIONID      VARCHAR(255),
    DEPLOYMENTTARGET   VARCHAR(200),
    FAILURETIME        TIMESTAMP,
    STATUS             INTEGER NOT NULL,
    EsQualified        SMALLINT,
    EventType              VARCHAR (10),
    CONSTRAINT PK_FAILEDEVENTS PRIMARY KEY(MSGID) )
IN @DB_NAME@.EVENTS;

CREATE UNIQUE INDEX @SCHEMA@.FAILEDEVENTS
 ON @SCHEMA@.FAILEDEVENTS (MSGID)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;

CREATE INDEX @SCHEMA@.FAILTIME
 ON @SCHEMA@.FAILEDEVENTS (FAILURETIME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@;

CREATE INDEX @SCHEMA@.FESTATUS
 ON @SCHEMA@.FAILEDEVENTS (STATUS)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@;
 
-- *******************************************
-- create table FailedEventBOTypes and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FAILEDEVENTBOTYPES (
    MSGID VARCHAR(255) NOT NULL,
    BOTYPE VARCHAR(255),
    ARGUMENT_POSITION INTEGER NOT NULL,
    CONSTRAINT PK_FAILEDEVENTBOTP
    PRIMARY KEY(MSGID, ARGUMENT_POSITION) )
IN @DB_NAME@.EVENTS0;

CREATE UNIQUE INDEX @SCHEMA@.FAILEDEVENTBOTYPES
 ON @SCHEMA@.FAILEDEVENTBOTYPES (MSGID, ARGUMENT_POSITION)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;


-- *******************************************
-- create table FailedEventMessage and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FAILEDEVENTMESSAGE (
    MSGID VARCHAR(255) NOT NULL,
    JSERVICEMESSAGE BLOB(1G),
    CONSTRAINT PK_FAILEDEVENTMSG PRIMARY KEY(MSGID) )
IN @DB_NAME@.EVENTS0;

CREATE UNIQUE INDEX @SCHEMA@.FAILEDEVENTMESSAGE
 ON @SCHEMA@.FAILEDEVENTMESSAGE (MSGID)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.FEMESSAGEBLOB
 IN @DB_NAME@.JSERVICE STORES @SCHEMA@.FAILEDEVENTMESSAGE
 COLUMN JSERVICEMESSAGE;

CREATE INDEX @SCHEMA@.FEMESSAGEBLOB_IDX
 ON @SCHEMA@.FEMESSAGEBLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

-- *******************************************
-- create table FailedEventDetail and indexes
-- *******************************************
CREATE LOB TABLESPACE EVENTSM
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE LOB TABLESPACE EVENTSP
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE LOB TABLESPACE EVENTSD
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE TABLE @SCHEMA@.FAILEDEVENTDETAIL
  (MSGID        VARCHAR(255) NOT NULL,
   MESSAGE      BLOB(1G),
   PARAMETERS       BLOB(1G),
   EXCEPTIONDETAIL  BLOB(10M),
   WrapperType          SMALLINT,
   APPLICATIONNAME  VARCHAR(255),
   CEITRACECONTROL  VARCHAR(255),
   UserIdentity     VARCHAR(128),
   EXPIRATIONTIME   TIMESTAMP,
   CONSTRAINT PK_FAILEDEVENTDTL PRIMARY KEY(MSGID))
IN @DB_NAME@.EVENTS0;

CREATE UNIQUE INDEX @SCHEMA@.FAILEDEVENTDETAIL
 ON @SCHEMA@.FAILEDEVENTDETAIL (MSGID)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.FEMMSGBLOB
 IN @DB_NAME@.EVENTSM STORES @SCHEMA@.FAILEDEVENTDETAIL COLUMN MESSAGE;

CREATE INDEX @SCHEMA@.FEMMSGM_IDX
 ON @SCHEMA@.FEMMSGBLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.FEMPRMBLOB
 IN @DB_NAME@.EVENTSP STORES @SCHEMA@.FAILEDEVENTDETAIL COLUMN PARAMETERS;

CREATE INDEX @SCHEMA@.FEMMSGP_IDX
 ON @SCHEMA@.FEMPRMBLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.FEMEXPBLOB
 IN @DB_NAME@.EVENTSD STORES @SCHEMA@.FAILEDEVENTDETAIL COLUMN
 EXCEPTIONDETAIL;

CREATE INDEX @SCHEMA@.FEMMSGE_IDX
 ON @SCHEMA@.FEMEXPBLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;
