-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or disclosure
--  restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

-- *******************************************
-- AppScheduler
-- *******************************************

CREATE TABLESPACE TEMPLATE
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 DEFINE NO
 SEGSIZE 32
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE TABLESPACE SCHWPTS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 DEFINE NO
 SEGSIZE 32
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE LOB TABLESPACE SCHWPTS1
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE TABLE @SCHEMA@.WSCH_TASK
(
  TASKID             NUMERIC(19)           NOT NULL ,
  VERSION            VARCHAR(5)            NOT NULL ,
  ROW_VERSION        INTEGER               NOT NULL ,
  TASKTYPE           INTEGER               NOT NULL ,
  TASKSUSPENDED      SMALLINT              NOT NULL ,
  CANCELLED          SMALLINT              NOT NULL ,
  NEXTFIRETIME       NUMERIC(19)           NOT NULL ,
  STARTBYINTERVAL    VARCHAR(254)                   ,
  STARTBYTIME        NUMERIC(19)                    ,
  VALIDFROMTIME      NUMERIC(19)                    ,
  VALIDTOTIME        NUMERIC(19)                    ,
  REPEATINTERVAL     VARCHAR(254)                   ,
  MAXREPEATS         INTEGER               NOT NULL ,
  REPEATSLEFT        INTEGER               NOT NULL ,
  TASKINFO           BLOB(102400)                   ,
  NAME               VARCHAR(254)          NOT NULL ,
  AUTOPURGE          INTEGER               NOT NULL ,
  FAILUREACTION      INTEGER                        ,
  MAXATTEMPTS        INTEGER                        ,
  QOS                INTEGER                        ,
  PARTITIONID        INTEGER                        ,
  OWNERTOKEN         VARCHAR(200)          NOT NULL ,
  CREATETIME         NUMERIC(19)           NOT NULL ,
  ROW_ID             ROWID                 NOT NULL GENERATED ALWAYS,
  PRIMARY KEY (TASKID)
)
IN @DB_NAME@.SCHWPTS;

CREATE UNIQUE INDEX @SCHEMA@.WSCH_TASKPK ON @SCHEMA@.WSCH_TASK (TASKID)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@;

CREATE INDEX @SCHEMA@.WSCH_TASK_IDX1 ON @SCHEMA@.WSCH_TASK 
(
 TASKID,
 OWNERTOKEN
)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;

CREATE INDEX @SCHEMA@.WSCH_TASK_IDX2 ON @SCHEMA@.WSCH_TASK
(
  NEXTFIRETIME ASC ,
  REPEATSLEFT ,
  PARTITIONID
)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.WSCH_TASK1
 IN @DB_NAME@.SCHWPTS1
 STORES @SCHEMA@.WSCH_TASK COLUMN TASKINFO;

CREATE UNIQUE INDEX @SCHEMA@.WSCH_TASK1I
 ON @SCHEMA@.WSCH_TASK1
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.WSCH_TREG
(
  REGKEY             VARCHAR(254)          NOT NULL ,
  REGVALUE           VARCHAR(254)                  ,
  PRIMARY KEY ( REGKEY )
)
IN @DB_NAME@.SCHWPTS;

 -- unique index for primary key
CREATE UNIQUE INDEX @SCHEMA@.WSCH_TREGPK
 ON @SCHEMA@.WSCH_TREG (REGKEY)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;

CREATE TABLE @SCHEMA@.WSCH_LMGR
(
  LEASENAME          VARCHAR(254)          NOT NULL ,
  LEASEOWNER         VARCHAR(254)          NOT NULL ,
  LEASE_EXPIRE_TIME  NUMERIC(19)                    ,
  DISABLED           VARCHAR(5)                     ,
  PRIMARY KEY (LEASENAME)
)
IN @DB_NAME@.SCHWPTS;

CREATE UNIQUE INDEX @SCHEMA@.WSCH_LMGRPK
 ON @SCHEMA@.WSCH_LMGR (LEASENAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;

CREATE TABLE @SCHEMA@.WSCH_LMPR
(
  LEASENAME          VARCHAR(254)          NOT NULL ,
  NAME               VARCHAR(254)          NOT NULL ,
  VALUE              VARCHAR(254)          NOT NULL ,
  PRIMARY KEY (LEASENAME)
)
IN @DB_NAME@.SCHWPTS;

CREATE UNIQUE INDEX @SCHEMA@.WSCH_LMPRPK
 ON @SCHEMA@.WSCH_LMPR (LEASENAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;


-- *******************************************
-- Customization
-- *******************************************

-- *******************************************
-- Create tablespaces
-- *******************************************
CREATE TABLESPACE BYTESTTS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 SEGSIZE 32
 DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE LOB TABLESPACE BBLOB1TS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE LOB TABLESPACE BBLOB2TS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

CREATE TABLESPACE APTIMETS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
  SEGSIZE 32  DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

-- *******************************************
-- Create table Bytestore and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.BYTESTORE
  (ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   INITIALBYTES BLOB(30000),
   TIMESTAMP1 DECIMAL(19,0) NOT NULL,
   FILENAME VARCHAR(250),
   BACKINGCLASS VARCHAR(250),
   CHARENCODING VARCHAR(50),
   APPNAME VARCHAR(200),
   COMPONENTTNS VARCHAR(250),
   COMPONENTNAME VARCHAR(200),
   SCAMODULENAME VARCHAR(200),
   SCACOMPONENTNAME VARCHAR(200),
   CONSTRAINT PK_BYTESTORE PRIMARY KEY
    (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME) )
IN @DB_NAME@.BYTESTTS;


CREATE UNIQUE INDEX @SCHEMA@.BSTORE_INDEX_PK 
ON @SCHEMA@.BYTESTORE (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE AUX TABLE @SCHEMA@.BYTESTORE_1 IN @DB_NAME@.BBLOB1TS
STORES @SCHEMA@.BYTESTORE COLUMN INITIALBYTES;

CREATE INDEX @SCHEMA@.BYTESTORE_1IDX ON @SCHEMA@.BYTESTORE_1
  USING STOGROUP @STOGRP@
  BUFFERPOOL @BPINDEX@ ;

-- *******************************************
-- Create table Bytestoreoverflow and indexes
-- *******************************************

CREATE TABLE @SCHEMA@.BYTESTOREOVERFLOW
  (ARTIFACTTYPE VARCHAR(50) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   SEQUENCENUMBER INTEGER NOT NULL,
   BYTES BLOB(30000),
   CONSTRAINT PK_BYTESTOREOVERFL PRIMARY KEY
    (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER) )
IN @DB_NAME@.BYTESTTS;

CREATE UNIQUE INDEX @SCHEMA@.BSTOREOVERFLOW_INDEX_PK 
ON @SCHEMA@.BYTESTOREOVERFLOW
    (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE AUX TABLE @SCHEMA@.BYTESTOREOVERFLOW_1 IN @DB_NAME@.BBLOB2TS
STORES @SCHEMA@.BYTESTOREOVERFLOW COLUMN BYTES;

CREATE INDEX @SCHEMA@.BYTESTOREOVERFLOW_1IDX
    ON @SCHEMA@.BYTESTOREOVERFLOW_1
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@ ;

-- *******************************************
-- Create table Apptimestamp and indexes
-- *******************************************

CREATE TABLE @SCHEMA@.APPTIMESTAMP
  (APPNAME VARCHAR(200) NOT NULL,
   TIMESTAMP1 DECIMAL(19,0) NOT NULL,
   CONSTRAINT PK_APPTIMESTAMP PRIMARY KEY (APPNAME) )
IN @DB_NAME@.APTIMETS;

CREATE UNIQUE INDEX @SCHEMA@.APPTIMESTAMP_INDEX_PK 
ON @SCHEMA@.APPTIMESTAMP (APPNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

-- *******************************************
-- Create the CUSTPROPERTIES table
-- *******************************************

CREATE TABLE @SCHEMA@.CUSTPROPERTIES
  (PROPERTYID VARCHAR (128) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   PNAME VARCHAR(250) NOT NULL,
   PVALUE VARCHAR(250) NOT NULL,
   PTYPE VARCHAR (16) NOT NULL,
   CONSTRAINT PK_CUSTPROPERTIES PRIMARY KEY (PROPERTYID) )
   IN @DB_NAME@.APTIMETS;

CREATE UNIQUE INDEX @SCHEMA@.CUSTPROP0_PK ON @SCHEMA@.CUSTPROPERTIES
    (PROPERTYID) USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE INDEX @SCHEMA@.CUSTPROP1_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTTNS)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;

CREATE INDEX @SCHEMA@.CUSTPROP2_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;
      
CREATE INDEX @SCHEMA@.CUSTPROP3_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTNAME, ARTIFACTTNS)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;      
  
CREATE INDEX @SCHEMA@.CUSTPROP4_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, PNAME) USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;        
           
CREATE INDEX @SCHEMA@.CUSTPROP5_PK ON @SCHEMA@.CUSTPROPERTIES
    (ARTIFACTTYPE, ARTIFACTTNS, PNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED ;                   


-- *******************************************
-- DirectDeploy
-- *******************************************

-- *******************************************
-- Create tablespaces
-- *******************************************
CREATE TABLESPACE D2D
IN @DB_NAME@ USING STOGROUP @STOGRP@
 CCSID UNICODE
 DEFINE NO
 SEGSIZE 32
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;
 
 CREATE LOB TABLESPACE D2DLOG
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

create table @SCHEMA@.d2d_item (
    id varchar(255) not null, 
    state varchar(20) not null,
    item_level int not null,
    module_name varchar(255),
    application_name varchar(255),
    version varchar(30), 
    wps_version varchar(10),
    new_app_name varchar(255),
    primary key (id))
    IN @DB_NAME@.D2D;

CREATE UNIQUE INDEX @SCHEMA@.D2DITEM_INDEX_PK 
ON @SCHEMA@.d2d_item (id)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;

create table @SCHEMA@.d2d_progress (
    item_id varchar(255) not null,
    progress INTEGER,
    progress_msg varchar(255),
    progress_error_code  varchar(255),
    primary key (item_id))
    IN @DB_NAME@.D2D;

CREATE UNIQUE INDEX @SCHEMA@.D2DPROGRESS_INDEX_PK 
ON @SCHEMA@.d2d_progress (item_id)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;
 
create table @SCHEMA@.d2d_content (
    item_id varchar(255) not null,
    pi  blob,
    primary key (item_id))
    IN @DB_NAME@.D2D;
    
CREATE UNIQUE INDEX @SCHEMA@.D2DCONTENT_INDEX_PK 
ON @SCHEMA@.d2d_content (item_id)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;
 
 CREATE AUX TABLE @SCHEMA@.D2DCONTENTBLOB
 IN @DB_NAME@.D2DLOG STORES @SCHEMA@.d2d_content
 COLUMN pi;

CREATE INDEX @SCHEMA@.D2DCONTENTBLOB_IDX
 ON @SCHEMA@.D2DCONTENTBLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;
 
create table @SCHEMA@.d2d_metadata(
    item_id varchar(255) not null,
    name varchar(255) not null,
    value varchar(255) )
    IN @DB_NAME@.D2D;

CREATE UNIQUE INDEX @SCHEMA@.D2DMETADATA_INDEX_PK 
ON @SCHEMA@.d2d_metadata (item_id, name, value)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;
 
create table @SCHEMA@.d2d_lock(
    item_lock character(1),
    lastUpdate timestamp)
    IN @DB_NAME@.D2D;

insert into @SCHEMA@.d2d_lock values ('x', null);

create table @SCHEMA@.d2d_message(
    item_id varchar(255) not null,
    seq int not null,
    id  varchar(63),
    description varchar(1024),
    affected_resource varchar(255),
    location varchar(63),
    folder varchar(255),
    chr varchar(63),
    tag varchar(63),
    severity varchar(15),
    time timestamp,
    primary key (item_id, seq))
    IN @DB_NAME@.D2D;
    
CREATE UNIQUE INDEX @SCHEMA@.D2DMESSAGE_INDEX_PK 
ON @SCHEMA@.d2d_message (item_id, seq)
 USING STOGROUP @STOGRP@
 DEFINE NO
 NOT PADDED
 BUFFERPOOL @BPINDEX@;

-- *******************************************
-- ESDLoggerMediation
-- *******************************************

-- Create Tablespaces
CREATE TABLESPACE ESBTS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 SEGSIZE 32
 DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE LOB TABLESPACE ESBCLOB
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

-- Create Tables
CREATE TABLE @SCHEMA@.MSGLOG
  (TIMESTAMP TIMESTAMP NOT NULL,
   MESSAGEID VARCHAR(36) NOT NULL,
   MEDIATIONNAME VARCHAR(256) NOT NULL,
   MODULENAME VARCHAR(256),
   MESSAGE CLOB(100000K),
   VERSION VARCHAR(10),
CONSTRAINT PK_MSGLOG PRIMARY KEY (MESSAGEID, TIMESTAMP, MEDIATIONNAME))
   IN @DB_NAME@.ESBTS;

CREATE UNIQUE INDEX @SCHEMA@.MSGLOG_INDEX_PK 
ON @SCHEMA@.MSGLOG (MESSAGEID, TIMESTAMP, MEDIATIONNAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;

-- Create AUX CLOB Tables/Index 
CREATE AUX TABLE @SCHEMA@.MESSAGECLOB
 IN @DB_NAME@.ESBCLOB STORES @SCHEMA@.MSGLOG COLUMN MESSAGE;

CREATE INDEX @SCHEMA@.MESSAGECLOB_IDX ON @SCHEMA@.MESSAGECLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;


-- *******************************************
-- GovernanceRepository
-- *******************************************

CREATE TABLESPACE EWSRR2
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_NAMESPACE  (
ID INTEGER NOT NULL ,
NAMESPACE VARCHAR(255) NOT NULL,Primary key(id),UNIQUE(NAMESPACE))
IN @DB_NAME@.EWSRR2;

CREATE UNIQUE INDEX @SCHEMA@.W_NAMESPACE1
ON @SCHEMA@.W_NAMESPACE(ID ASC);

CREATE UNIQUE INDEX  @SCHEMA@.W_NAME_SPC1
ON @SCHEMA@.W_NAMESPACE(NAMESPACE ASC);

------------------------------------------------
-- DDL Statements for table @SCHEMA@.W_STATEMENT
------------------------------------------------


CREATE TABLESPACE EWSRR3
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_STATEMENT  (
ID INTEGER NOT NULL  ,
VERSION_FROM INTEGER NOT NULL ,
VERSION_TO INTEGER ,
PRED_ID INTEGER NOT NULL ,
SUBJ_ID INTEGER NOT NULL ,
OBJ_ID INTEGER NOT NULL ,
OBJ_TYP_CD INTEGER NOT NULL ,
PARTITION_ID INTEGER NOT NULL,Primary key(id) )
IN @DB_NAME@.EWSRR3;

CREATE UNIQUE INDEX @SCHEMA@.W_STATEMENT1
ON @SCHEMA@.W_STATEMENT(ID ASC);

CREATE INDEX @SCHEMA@.IDX_SBJ_BY_PRP
ON @SCHEMA@.W_STATEMENT 
  (PRED_ID ASC,OBJ_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SBJ_BY_VAL
ON @SCHEMA@.W_STATEMENT (OBJ_ID ASC, SUBJ_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SMT_BY_SBJ
ON @SCHEMA@.W_STATEMENT (SUBJ_ID ASC, VERSION_FROM ASC, 
   VERSION_TO ASC);

CREATE INDEX @SCHEMA@.IDX_VAL_BY_PRP
ON @SCHEMA@.W_STATEMENT (SUBJ_ID ASC,PRED_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SMT_BY_FVR
ON @SCHEMA@.W_STATEMENT (VERSION_FROM ASC);



------------------------------------------------
-- DDL Statements for table W_URI
------------------------------------------------


CREATE TABLESPACE EWSRR4
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_URI  (
ID INTEGER NOT NULL ,
URI VARCHAR(255) NOT NULL ,
NAMESPACE_ID INTEGER NOT NULL,Primary key(id),UNIQUE(URI))
IN @DB_NAME@.EWSRR4;

ALTER TABLE @SCHEMA@.W_URI
ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY
(NAMESPACE_ID)
REFERENCES @SCHEMA@.W_NAMESPACE
(ID)
ON DELETE NO ACTION
ENFORCED
ENABLE QUERY OPTIMIZATION;

CREATE UNIQUE INDEX @SCHEMA@.W_URI1
ON @SCHEMA@.W_URI (ID ASC);

CREATE UNIQUE INDEX  @SCHEMA@.W_URI
ON @SCHEMA@.W_URI(URI ASC);

------------------------------------------------
-- DDL Statements for table W_VERSION
------------------------------------------------

CREATE TABLESPACE EWSRR5
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_VERSION  (
ID INTEGER NOT NULL ,
PARTITION_ID INTEGER NOT NULL,
USERNAME VARCHAR(64) NOT NULL ,
CHANGE_TIME TIMESTAMP NOT NULL ,
CL_GID VARCHAR(36) ,
CL_LID VARCHAR(10) ,
SCHEMA_NS_ID INTEGER ,
SCHEMA_REV INTEGER NOT NULL )
IN @DB_NAME@.EWSRR5;

CREATE INDEX @SCHEMA@.W_VERSION1
ON @SCHEMA@.W_VERSION(ID ASC);

CREATE INDEX @SCHEMA@.W_VERSION2
ON @SCHEMA@.W_VERSION (SCHEMA_NS_ID);

CREATE UNIQUE INDEX @SCHEMA@.W_VERS_IN2
ON @SCHEMA@.W_VERSION(ID ASC, PARTITION_ID ASC);

ALTER TABLE @SCHEMA@.W_VERSION
    ADD PRIMARY KEY (ID, PARTITION_ID);

ALTER TABLE @SCHEMA@.W_VERSION
ADD CONSTRAINT W_VER_FK_NAMESP FOREIGN KEY
(SCHEMA_NS_ID)
REFERENCES @SCHEMA@.W_NAMESPACE
(ID)
ON DELETE NO ACTION
ENFORCED
ENABLE QUERY OPTIMIZATION;

------------------------------------------------
-- DDL Statements for table W_OBJ_LIT_ANY
------------------------------------------------

CREATE TABLESPACE EWSRR6
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_ANY  (
ID INTEGER NOT NULL ,
TYPE_URI VARCHAR(255) NOT NULL ,
HASH VARCHAR(40) ,
LARGE BLOB(10000000),Primary key(id) )
IN @DB_NAME@.EWSRR6;

CREATE UNIQUE INDEX @SCHEMA@.W_OBJ_LIT_ANY1
ON @SCHEMA@.W_OBJ_LIT_ANY(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_ANY
ON @SCHEMA@.W_OBJ_LIT_ANY (TYPE_URI ASC);

CREATE LOB TABLESPACE EWSRR6L               
  IN @DB_NAME@                               
  USING STOGROUP @STOGRP@                    
  LOCKSIZE LOB                              
  BUFFERPOOL @BPLOB4K@;                           
                                            
CREATE AUX TABLE @SCHEMA@.W_OBJ_LIT_ANYAUX    
 IN @DB_NAME@.EWSRR6L                        
 STORES @SCHEMA@.W_OBJ_LIT_ANY COLUMN LARGE;  
                                            
CREATE INDEX @SCHEMA@.W_OBJ_LIT_ANYAUX_IDX    
 ON @SCHEMA@.W_OBJ_LIT_ANYAUX                 
 USING STOGROUP @STOGRP@                     
 BUFFERPOOL @BPINDEX@;                            

------------------------------------------------
-- DDL Statements for table W_LIT_DOUBLE
------------------------------------------------


CREATE TABLESPACE EWSRR9
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LIT_DOUBLE  (
ID INTEGER NOT NULL ,
LITVAL DOUBLE,Primary key(id) )
IN @DB_NAME@.EWSRR9;

CREATE UNIQUE INDEX @SCHEMA@.W_LIT_DOUBLE1
ON @SCHEMA@.W_LIT_DOUBLE(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_DBL
ON @SCHEMA@.W_LIT_DOUBLE (LITVAL ASC);

------------------------------------------------
-- DDL Statements for table W_LIT_FLOAT
------------------------------------------------


CREATE TABLESPACE EWSRR10
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LIT_FLOAT  (
ID INTEGER NOT NULL ,
LITVAL DOUBLE,Primary key(id) )
IN @DB_NAME@.EWSRR10;

CREATE UNIQUE INDEX @SCHEMA@.W_LIT_FLOAT1
ON @SCHEMA@.W_LIT_FLOAT(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_FLT
ON @SCHEMA@.W_LIT_FLOAT (LITVAL ASC);


------------------------------------------------
-- DDL Statements for table W_LIT_LONG
------------------------------------------------


CREATE TABLESPACE EWSRR12
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LIT_LONG  (
ID INTEGER NOT NULL ,
LITVAL DECIMAL(19, 0),Primary key(id) )
IN @DB_NAME@.EWSRR12;

CREATE UNIQUE INDEX @SCHEMA@.W_LIT_LONG1
ON @SCHEMA@.W_LIT_LONG(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_LONG
ON @SCHEMA@.W_LIT_LONG (LITVAL ASC);

------------------------------------------------
-- DDL Statements for table W_OBJ_LIT_DATE
------------------------------------------------


CREATE TABLESPACE EWSRR13
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_DATE  (
ID INTEGER NOT NULL ,
LITVAL TIMESTAMP,Primary key(id) )
IN @DB_NAME@.EWSRR13;

CREATE UNIQUE INDEX @SCHEMA@.W_OBJ_LIT_DATE1
ON @SCHEMA@.W_OBJ_LIT_DATE(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_DATE
ON @SCHEMA@.W_OBJ_LIT_DATE (LITVAL ASC);

------------------------------------------------
-- DDL Statements for table W_OBJ_LIT_DATETIME
------------------------------------------------


CREATE TABLESPACE EWSRR14
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_DATETIME  (
ID INTEGER NOT NULL ,
LITVAL TIMESTAMP,Primary key(id) )
IN @DB_NAME@.EWSRR14;

CREATE UNIQUE INDEX @SCHEMA@.W_OBJ_LIT_DATETIME1
ON @SCHEMA@.W_OBJ_LIT_DATETIME(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_TIME
ON @SCHEMA@.W_OBJ_LIT_DATETIME (LITVAL ASC);

-- DDL Statements for table W_OBJ_LIT_STRING
------------------------------------------------

CREATE TABLESPACE EWSRR15
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_STRING (
ID  INTEGER NOT NULL  ,
HASH VARCHAR(40) ,
LITVAL VARCHAR(1024) ,
LARGE BLOB(10000000) ,Primary key(id))
IN @DB_NAME@.EWSRR15;

CREATE UNIQUE INDEX  @SCHEMA@.W_OBJ_LIT_STRING1
ON @SCHEMA@.W_OBJ_LIT_STRING(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_STR
ON @SCHEMA@.W_OBJ_LIT_STRING (HASH ASC);

CREATE LOB TABLESPACE EWSRR15L                     
  IN @DB_NAME@                                     
  USING STOGROUP @STOGRP@
  LOCKSIZE LOB                                    
  BUFFERPOOL @BPLOB4K@;                                 
                                                  
CREATE AUX TABLE @SCHEMA@.W_OBJ_LIT_STRINGAUX              
   IN @DB_NAME@.EWSRR15L                            
   STORES @SCHEMA@.W_OBJ_LIT_STRING COLUMN LARGE;   
                                                  
CREATE INDEX @SCHEMA@.W_OBJ_LIT_STRINGAUX_IDX       
 ON @SCHEMA@.W_OBJ_LIT_STRINGAUX                    
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

------------------------------------------------
-- DDL Statements for table W_ARTIFACT_BLOB
------------------------------------------------


CREATE TABLESPACE EWSRR16
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_ARTIFACT_BLOB (
 ID VARCHAR(254) NOT NULL,
 CONTENT BLOB(1G), 
 DELETED SMALLINT, Primary key(id))
IN @DB_NAME@.EWSRR16;

CREATE UNIQUE INDEX @SCHEMA@.W_ARTIFACT_BLOB1
ON @SCHEMA@.W_ARTIFACT_BLOB (ID ASC);

CREATE LOB TABLESPACE EWSRR16L                    
  IN @DB_NAME@                                     
  USING STOGROUP @STOGRP@                          
  LOCKSIZE LOB                                    
  BUFFERPOOL @BPLOB4K@;                                 
                                                  
CREATE AUX TABLE @SCHEMA@.W_ARTIFACT_BLOBAUX       
   IN @DB_NAME@.EWSRR16L                          
   STORES @SCHEMA@.W_ARTIFACT_BLOB COLUMN CONTENT; 
                                                  
CREATE INDEX @SCHEMA@.W_ARTIFACT_BLOBAUX_IDX        
 ON @SCHEMA@.W_ARTIFACT_BLOBAUX                     
 USING STOGROUP @STOGRP@                           
 BUFFERPOOL @BPINDEX@;                                  
 
 
------------------------------------------------
-- DDL Statements for table W_LOCALE
------------------------------------------------

CREATE TABLESPACE EWSRR17
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LOCALE (
 ID INTEGER NOT NULL,
 LOCALE VARCHAR(8) NOT NULL,Primary key(id))
IN @DB_NAME@.EWSRR17;

CREATE UNIQUE INDEX @SCHEMA@.W_LOCALE1
ON @SCHEMA@.W_LOCALE(ID ASC);

INSERT INTO @SCHEMA@.W_LOCALE VALUES (1000, '');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1001, 'en');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1002, 'en-us');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1003, 'en-uk');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1004, 'en-gb');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1032, 'cs');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1064, 'es');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1096, 'de');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1128, 'de-de');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1129, 'fr');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1160, 'fr-ca-sk');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1161, 'hu');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1192, 'it');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1224, 'ja');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1256, 'ko');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1288, 'pl');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1320, 'pt-br');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1352, 'ru');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1384, 'zh');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1416, 'zh-tw');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1448, 'el');


----------------------------------------------------------
---Creating sequence objects for Triple store
----------------------------------------------------------

CREATE SEQUENCE @SCHEMA@.SEQ_W_LIT_DOUBLE_ID
 as integer START WITH 1000 increment by 1
 no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_LIT_FLOAT_ID
as integer START WITH 1000 increment by 1
 no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_LIT_LONG_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_NAMESPACE_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_ANY_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_DATE_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_DATETIME_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_STRING_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_STATEMENT_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_URI_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_VERSION_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

--
--

-- Pattern tables for query optimization

CREATE TABLESPACE EWSRR18
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_subj_pred_index (
    subj_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, version_from, version_to, partition_id)
) IN @DB_NAME@.EWSRR18;

CREATE UNIQUE INDEX @SCHEMA@.w_subj_pred_idx
 ON @SCHEMA@.w_subj_pred_index(subj_id, version_from, version_to,
    partition_id);

CREATE TABLESPACE EWSRR19
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_subj_obj_index (
    subj_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, obj_typ_cd, version_from, version_to,
      partition_id)
) IN @DB_NAME@.EWSRR19;

CREATE UNIQUE INDEX @SCHEMA@.w_subj_obj_idx
 ON @SCHEMA@.w_subj_obj_index(subj_id, obj_typ_cd, version_from, 
   version_to, partition_id);

CREATE TABLESPACE EWSRR20
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_pred_subj_index (
    pred_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, version_from, version_to, partition_id)
) IN @DB_NAME@.EWSRR20;

CREATE UNIQUE INDEX @SCHEMA@.w_pred_subj_idx
 ON @SCHEMA@.w_pred_subj_index(pred_id, version_from, version_to, 
   partition_id);

CREATE TABLESPACE EWSRR21
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_pred_obj_index (
    pred_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, obj_typ_cd, version_from, version_to, 
     partition_id)
) IN @DB_NAME@.EWSRR21;

CREATE UNIQUE INDEX @SCHEMA@.w_pred_obj_idx
 ON @SCHEMA@.w_pred_obj_index(pred_id, obj_typ_cd, version_from,
   version_to, partition_id);

CREATE TABLESPACE EWSRR22
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_obj_subj_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, 
       version_to, partition_id)
) IN @DB_NAME@.EWSRR22;

CREATE UNIQUE INDEX @SCHEMA@.w_obj_subj_idx
 ON @SCHEMA@.w_obj_subj_index(obj_id, obj_typ_cd, version_from, 
  version_to, partition_id);

CREATE TABLESPACE EWSRR23
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_obj_pred_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to,
      partition_id)
) IN @DB_NAME@.EWSRR23;

CREATE UNIQUE INDEX @SCHEMA@.w_obj_pred_idx
 ON @SCHEMA@.w_obj_pred_index(obj_id, obj_typ_cd, version_from,
   version_to, partition_id);


------------------------------------------------
-- DDL Statements for table W_DBVERSION
------------------------------------------------

CREATE TABLESPACE EWSRR1
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_DBVERSION (
 SUBSYSTEM VARCHAR(8) NOT NULL , 
 CUR_VERSION INTEGER NOT NULL)
IN @DB_NAME@.EWSRR1;

CREATE UNIQUE INDEX @SCHEMA@.W_DBVERSON1
ON @SCHEMA@.W_DBVERSION(SUBSYSTEM ASC);


-- *******************************************
-- Mediation
-- *******************************************

-- *******************************************
-- Create tablespaces
-- *******************************************
CREATE TABLESPACE MEDTS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 SEGSIZE 32
 DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@;

CREATE LOB TABLESPACE TICKETTS
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL @BPLOB4K@;

-- *******************************************
-- Create mediatoin table and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.MEDIATION_TICKETS (
    TARGETTICKETID VARCHAR(255) NOT NULL,
    TICKETENTRY BLOB(1G),
    VERSION VARCHAR(255) NOT NULL,
    CONSTRAINT PK_MEDTS PRIMARY KEY (TARGETTICKETID) ) 
IN @DB_NAME@.MEDTS;

CREATE UNIQUE INDEX @SCHEMA@.MEDTICKETS_INDEX_PK 
ON @SCHEMA@.MEDIATION_TICKETS (TARGETTICKETID)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;

CREATE AUX TABLE @SCHEMA@.TICKETBLOB
 IN @DB_NAME@.TICKETTS
STORES @SCHEMA@.MEDIATION_TICKETS COLUMN TICKETENTRY; 

CREATE INDEX @SCHEMA@.TICKETBLOB_IDX
 ON @SCHEMA@.TICKETBLOB
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

-- *******************************************
-- RelationshipService
-- *******************************************
CREATE TABLESPACE RELTS0
 IN @DB_NAME@
 USING STOGROUP @STOGRP@
 CCSID UNICODE
 SEGSIZE 32
 DEFINE NO
 LOCKSIZE ANY
 BUFFERPOOL @BPTABLE4K@ ;
 
CREATE TABLE @SCHEMA@.RELN_METADATA_T(RELATIONSHIP_NAME VARCHAR(255)
 NOT NULL, VERSION VARCHAR(10) NOT NULL) IN @DB_NAME@.RELTS0;

CREATE UNIQUE INDEX @SCHEMA@.RMT_RELN_NAME_I
 ON @SCHEMA@.RELN_METADATA_T (RELATIONSHIP_NAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;


CREATE TABLE @SCHEMA@.RELN_VIEW_META_T
( 
 VIEW_NAME VARCHAR(255) NOT NULL,
 RELATIONSHIP_NAME VARCHAR(255) NOT NULL,
 ROLE_NAME VARCHAR(255) NOT NULL,
 VERSION VARCHAR(10) NOT NULL
)
 IN @DB_NAME@.RELTS0;
                                        
CREATE UNIQUE INDEX @SCHEMA@.RELN_VIEW_I
 ON @SCHEMA@.RELN_VIEW_META_T (RELATIONSHIP_NAME, ROLE_NAME)
 USING STOGROUP @STOGRP@
 DEFINE NO
 BUFFERPOOL @BPINDEX@
 NOT PADDED;
