-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or disclosure
--  restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

create table @SCHEMA@.persistentlock (
    lockId integer not null,
    sequenceId integer not null,
    owner integer not null,
    moduleName varchar2 (250),
    compName varchar2 (250),
    method varchar2 (250),
    msgHandleString varchar2 (128),
    primary key (lockId,sequenceId));

-- *******************************************
-- create table FailedEvents and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEvents
  (MsgId            VARCHAR2 (255) NOT NULL,
   Destination_Module_Name  VARCHAR2 (255),
   Destination_Component_Name   VARCHAR2 (255),
   Destination_Method_Name  VARCHAR2 (255),
   Source_Module_Name       VARCHAR2 (255),
   Source_Component_Name    VARCHAR2 (255),
   ResubmitDestination      VARCHAR2 (512),
   InteractionType      VARCHAR2 (128),
   ExceptionDetails     VARCHAR2 (1024),
   SessionId            VARCHAR2 (255),
   CorrelationId        VARCHAR2 (255),
   DeploymentTarget     VARCHAR2 (200),
   FailureTime          DATE NOT NULL,
   Status           INTEGER NOT NULL,
   EsQualified              SMALLINT,
   EventType        VARCHAR (10));

ALTER TABLE @SCHEMA@.FailedEvents
   ADD CONSTRAINT PK_FailedEvents PRIMARY KEY (MsgId);

CREATE INDEX @SCHEMA@.INX_FEDest ON @SCHEMA@.FailedEvents
  (Destination_Module_Name,
   Destination_Component_Name,
   Destination_Method_Name);

CREATE INDEX @SCHEMA@.INX_FESrc ON @SCHEMA@.FailedEvents
  (Source_Module_Name,
   Source_Component_Name);

CREATE INDEX @SCHEMA@.INX_FESID ON @SCHEMA@.FailedEvents (SessionId);

CREATE INDEX @SCHEMA@.INX_FEFTime ON @SCHEMA@.FailedEvents (FailureTime);

CREATE INDEX @SCHEMA@.INX_FEESQualified ON @SCHEMA@.FailedEvents (EsQualified);

CREATE INDEX @SCHEMA@.INX_FEEventType ON @SCHEMA@.FailedEvents (EventType);

-- *******************************************
-- create table FailedEventBOTypes and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEventBOTypes
  (MsgId        VARCHAR2 (255) NOT NULL,
   BOType       VARCHAR2 (255) NOT NULL,
   Argument_Position    INTEGER NOT NULL);

ALTER TABLE @SCHEMA@.FailedEventBOTypes
   ADD CONSTRAINT PK_FailedEventBO PRIMARY KEY (MsgId, Argument_Position);

ALTER TABLE @SCHEMA@.FailedEventBOTypes
   ADD CONSTRAINT FK_FailedEventBO FOREIGN KEY (MsgId) REFERENCES @SCHEMA@.FailedEvents(MsgId);

CREATE INDEX @SCHEMA@.FailedEventBOTp ON @SCHEMA@.FailedEventBOTypes (BOType);

-- *******************************************
-- create table FailedEventMessage and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEventMessage
  (MsgId        VARCHAR2 (255) NOT NULL,
   JserviceMessage  LONG RAW);

ALTER TABLE @SCHEMA@.FailedEventMessage
   ADD CONSTRAINT PK_FailedEventMSG PRIMARY KEY (MsgId);

ALTER TABLE @SCHEMA@.FailedEventMessage
   ADD CONSTRAINT FK_FailedEventMSG FOREIGN KEY (MsgId) REFERENCES @SCHEMA@.FailedEvents(MsgId);

-- *******************************************
-- create table FailedEventDetail and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEventDetail
  (MsgId        VARCHAR (255) NOT NULL,
   Message      BLOB,
   Parameters       BLOB,
   ExceptionDetail  BLOB,
   WrapperType          SMALLINT,
   ApplicationName  VARCHAR (255),
   CEITraceControl  VARCHAR (255),
   UserIdentity     VARCHAR(128),
   ExpirationTime   TIMESTAMP);

ALTER TABLE @SCHEMA@.FailedEventDetail
   ADD CONSTRAINT PK_FailedEventDTL PRIMARY KEY (MsgId);

ALTER TABLE @SCHEMA@.FailedEventDetail
   ADD CONSTRAINT FK_FailedEventDTL FOREIGN KEY (MsgId) REFERENCES @SCHEMA@.FailedEvents(MsgId);
