-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96, 5724-M24
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or
--  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

-- Script file to create schema (tables) for Oracle
--
---------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script: 
-- @SCHEMA@ = the schema owner, eg MONITOR
-- @TSDIR@ = the directory or prefix for tablespace datafiles, eg DEFAULTTS
--
--
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @createTables.sql
--
-- ------------------------------------------------------------------------------------

---------- EVENT SOURCE TABLES

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR2(256)       NOT NULL ,
  SOURCE_TYPE                        NUMBER(5,0)                  ,
  PRIMARY KEY ( SOURCE_ID ) USING INDEX 
-- TABLESPACE MONIDXTS
);
-- TABLESPACE MONDSTS
-- LOGGING


CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR2(256)       NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(512)                ,  
  DATA_SOURCE_JNDI                   VARCHAR2(256)                ,
  SCHEMA_NAME                        VARCHAR2(128)                ,
  HOST                               VARCHAR2(128)                ,
  PORT                               NUMBER(10,0)                 ,
  AUTH_ALIAS                         VARCHAR2(128)                ,
  REMOTE_ID                          VARCHAR2(256)                ,
  IS_SECURITY_ENABLED                NUMBER(5,0)                  ,
  IS_LOCAL                           NUMBER(5,0)                  ,
  IS_EVENT_PRODUCER                  NUMBER(5,0)                  ,
  IS_EVENT_CONSUMER                  NUMBER(5,0)                  ,
  DE_NAME                            VARCHAR2(256)                ,  
  DE_PROPERTIES                      BLOB                         ,
  PRIMARY KEY ( SOURCE_ID ) USING INDEX							  ,
--  TABLESPACE MONIDXTS       ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
);
-- TABLESPACE MONDSTS
--  LOGGING

CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR2(256)       NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(512)                ,  
  HOST                               VARCHAR2(128)                ,
  PORT                               NUMBER(10,0)                 ,
  AUTH_ALIAS                         VARCHAR2(128)                ,  
  SCOPE_TYPE                         NUMBER(5,0)                  ,
  SCOPE_VALUE                        VARCHAR2(512)                ,
  EVENT_GROUP_PROFILE_LIST           VARCHAR2(128)                ,
  DE_NAME                            VARCHAR2(256)                ,  
  DE_PROPERTIES                      BLOB                         ,
  PRIMARY KEY ( SOURCE_ID ) USING INDEX							  ,
--  TABLESPACE MONIDXTS       ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
); 
-- TABLESPACE MONDSTS
--  LOGGING


CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  EVENT_SOURCE_ID                    VARCHAR2(256)       NOT NULL ,
  PROCESSING_MODE                    NUMBER(5,0)                  ,
  RECORDING_EVENTS                   NUMBER(5,0)                  ,
  IS_DELETED                         NUMBER(5,0)                  ,
  ROUTER_TYPE                        VARCHAR2(128)                ,  
  ROUTING_PROPERTIES                 BLOB                         ,
  PRIMARY KEY ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) USING INDEX  ,
--  TABLESPACE MONIDXTS ,
  FOREIGN KEY ( EVENT_SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID )
); 
-- TABLESPACE MONDSTS
--  LOGGING


CREATE TABLE @SCHEMA@.ES_SUBSCRIPTION_FILTERS_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  EVENT_CONSUMER_ID                  VARCHAR2(256)       NOT NULL ,
  GU_ID                              VARCHAR2(128)       NOT NULL ,
  EVENT_FILTER                       VARCHAR2(4000)               ,
  PRIMARY KEY ( MODEL_ID, VERSION, EVENT_CONSUMER_ID, GU_ID ) USING INDEX
--  TABLESPACE MONIDXTS
); 
-- TABLESPACE MONDSTS
--  LOGGING

